import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, GridControlBase } from '@/studio-core';
import HRTechnicalTitleService from '@/service/hrtechnical-title/hrtechnical-title-service';
import GRID_001Service from './grid-001-grid-service';
import HRTechnicalTitleUIService from '@/uiservice/hrtechnical-title/hrtechnical-title-ui-service';
import { FormItemModel } from '@/model/form-detail';


/**
 * grid部件基类
 *
 * @export
 * @class GridControlBase
 * @extends {GRID_001GridBase}
 */
export class GRID_001GridBase extends GridControlBase {

    /**
     * 获取部件类型
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected controlType: string = 'GRID';

    /**
     * 建构部件服务对象
     *
     * @type {GRID_001Service}
     * @memberof GRID_001GridBase
     */
    public service: GRID_001Service = new GRID_001Service({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {HRTechnicalTitleService}
     * @memberof GRID_001GridBase
     */
    public appEntityService: HRTechnicalTitleService = new HRTechnicalTitleService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeName: string = 'hrtechnicaltitle';

    /**
     * 应用实体中文名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeLogicName: string = '职称信息';

    /**
     * 界面UI服务对象
     *
     * @type {HRTechnicalTitleUIService}
     * @memberof GRID_001Base
     */  
    public appUIService:HRTechnicalTitleUIService = new HRTechnicalTitleUIService(this.$store);

    /**
     * 界面行为模型
     *
     * @type {*}
     * @memberof GRID_001Base
     */  
    public ActionModel: any = {
    };

    /**
     * 本地缓存标识
     *
     * @protected
     * @type {string}
     * @memberof GRID_001Base
     */
    protected localStorageTag: string = 'hrtechnicaltitle_grid_001_grid';

    /**
     * 所有列成员
     *
     * @type {any[]}
     * @memberof GRID_001GridBase
     */
    public allColumns: any[] = [
        {
            name: 'hrtechnicaltitlename',
            label: '职称名称',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.hrtechnicaltitlename',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'titlelevel',
            label: '职称等级',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.titlelevel',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'majortype',
            label: '专业类别',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.majortype',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'major',
            label: '专业名称',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.major',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'titletime',
            label: '获取时间',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.titletime',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'authorganization',
            label: '签发机构',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.authorganization',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'hightitle',
            label: '最高职称',
            langtag: 'entities.hrtechnicaltitle.grid_001_grid.columns.hightitle',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
    ]

    /**
     * 获取表格行模型
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public getGridRowModel(){
        return {
          srfkey: new FormItemModel(),
        }
    }

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public rules: any = {
        srfkey: [
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '职称信息标识 值不能为空', trigger: 'change' },
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '职称信息标识 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 获取对应列class
     *
     * @type {*}
     * @memberof GRID_001Base
     */
    public hasRowEdit: any = {
        'hrtechnicaltitlename':false,
        'titlelevel':false,
        'majortype':false,
        'major':false,
        'titletime':false,
        'authorganization':false,
        'hightitle':false,
    };

    /**
     * 获取对应列class
     *
     * @param {*} $args row 行数据，column 列数据，rowIndex 行索引，列索引
     * @returns {void}
     * @memberof GRID_001Base
     */
    public getCellClassName(args: {row: any, column: any, rowIndex: number, columnIndex: number}): any {
        return ( this.hasRowEdit[args.column.property] && this.actualIsOpenEdit ) ? "edit-cell" : "info-cell";
    }


    /**
     * 导出数据格式化
     *
     * @param {*} filterVal
     * @param {*} jsonData
     * @param {any[]} [codelistColumns=[]]
     * @returns {Promise<any>}
     * @memberof GRID_001GridBase
     */
    public async formatExcelData(filterVal: any, jsonData: any, codelistColumns?: any[]): Promise<any> {
        return super.formatExcelData(filterVal, jsonData, [
            {
                name: 'titlelevel',
                srfkey: 'CL_HR_0023',
                codelistType : 'STATIC',
                renderMode: 'other',
                textSeparator: '、',
                valueSeparator: ',',
            },
            {
                name: 'hightitle',
                srfkey: 'YesNo',
                codelistType : 'STATIC',
                renderMode: 'other',
                textSeparator: '、',
                valueSeparator: ',',
            },
        ]);
    }

}